package org.cocos2dx.javascript;

import android.content.Context;
import android.content.Intent;
import android.content.res.Configuration;
import android.opengl.GLSurfaceView;
import android.os.Bundle;
import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;
import java.util.ArrayList;
import java.util.List;
import org.cocos2dx.javascript.service.SDKClass;
import org.json.JSONArray;
import org.json.JSONObject;
/* loaded from: classes.dex */
public class SDKWrapper {
    private static SDKWrapper mInstace;
    private Context mainActive = null;
    private List<SDKClass> sdkClasses;

    public static SDKWrapper getInstance() {
        if (mInstace == null) {
            mInstace = new SDKWrapper();
        }
        return mInstace;
    }

    private String getJson(Context context, String str) {
        StringBuilder sb = new StringBuilder();
        try {
            BufferedReader bufferedReader = new BufferedReader(new InputStreamReader(context.getAssets().open(str)));
            while (true) {
                String readLine = bufferedReader.readLine();
                if (readLine == null) {
                    break;
                }
                sb.append(readLine);
            }
        } catch (IOException e) {
            e.printStackTrace();
            sb.delete(0, sb.length());
        }
        return sb.toString().trim();
    }

    public Context getContext() {
        return this.mainActive;
    }

    public void init(Context context) {
        this.mainActive = context;
        for (SDKClass sDKClass : this.sdkClasses) {
            sDKClass.init(context);
        }
    }

    public void loadSDKClass() {
        JSONArray jSONArray;
        ArrayList arrayList = new ArrayList();
        try {
            jSONArray = new JSONObject(getJson(this.mainActive, "project.json")).getJSONArray("serviceClassPath");
        } catch (Exception e) {
            e.printStackTrace();
        }
        if (jSONArray == null) {
            return;
        }
        int length = jSONArray.length();
        for (int i = 0; i < length; i++) {
            arrayList.add((SDKClass) Class.forName(jSONArray.getString(i)).newInstance());
        }
        this.sdkClasses = arrayList;
    }

    public void onActivityResult(int i, int i2, Intent intent) {
        for (SDKClass sDKClass : this.sdkClasses) {
            sDKClass.onActivityResult(i, i2, intent);
        }
    }

    public void onBackPressed() {
        for (SDKClass sDKClass : this.sdkClasses) {
            sDKClass.onBackPressed();
        }
    }

    public void onConfigurationChanged(Configuration configuration) {
        for (SDKClass sDKClass : this.sdkClasses) {
            sDKClass.onConfigurationChanged(configuration);
        }
    }

    public void onDestroy() {
        for (SDKClass sDKClass : this.sdkClasses) {
            sDKClass.onDestroy();
        }
    }

    public void onNewIntent(Intent intent) {
        for (SDKClass sDKClass : this.sdkClasses) {
            sDKClass.onNewIntent(intent);
        }
    }

    public void onPause() {
        for (SDKClass sDKClass : this.sdkClasses) {
            sDKClass.onPause();
        }
    }

    public void onRestart() {
        for (SDKClass sDKClass : this.sdkClasses) {
            sDKClass.onRestart();
        }
    }

    public void onRestoreInstanceState(Bundle bundle) {
        for (SDKClass sDKClass : this.sdkClasses) {
            sDKClass.onRestoreInstanceState(bundle);
        }
    }

    public void onResume() {
        for (SDKClass sDKClass : this.sdkClasses) {
            sDKClass.onResume();
        }
    }

    public void onSaveInstanceState(Bundle bundle) {
        for (SDKClass sDKClass : this.sdkClasses) {
            sDKClass.onSaveInstanceState(bundle);
        }
    }

    public void onStart() {
        for (SDKClass sDKClass : this.sdkClasses) {
            sDKClass.onStart();
        }
    }

    public void onStop() {
        for (SDKClass sDKClass : this.sdkClasses) {
            sDKClass.onStop();
        }
    }

    public void setGLSurfaceView(GLSurfaceView gLSurfaceView, Context context) {
        this.mainActive = context;
        loadSDKClass();
        for (SDKClass sDKClass : this.sdkClasses) {
            sDKClass.setGLSurfaceView(gLSurfaceView);
        }
    }
}
